@@ -2,14 +2,14 @@
  
 """
 Name: 'Wavefront (.obj)...'
-Blender: 242
+Blender: 249
 Group: 'Import'
 Tooltip: 'Load a Wavefront OBJ File, Shift: batch import all dir.'
 """
 
-__author__= "Campbell Barton", "Jiri Hnidek"
-__url__= ["blender.org", "blenderartists.org"]
-__version__= "2.0"
+__author__= "Campbell Barton", "Jiri Hnidek", "Paolo Ciccone"
+__url__= ['http://wiki.blender.org/index.php/Scripts/Manual/Import/wavefront_obj', 'blender.org', 'blenderartists.org']
+__version__= "2.13"
 
 __bpydoc__= """\
 This script imports a Wavefront OBJ files to Blender.
@@ -21,7 +21,8 @@ Note, This loads mesh objects and materials only, nurbs and curves are not suppo
 
 # ***** BEGIN GPL LICENSE BLOCK *****
 #
-# Script copyright (C) Campbell J Barton 2007
+# Script copyright (C) Campbell J Barton 2007-2009
+# - V2.12- bspline import/export added (funded by PolyDimensions GmbH)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -40,7 +41,7 @@ Note, This loads mesh objects and materials only, nurbs and curves are not suppo
 # ***** END GPL LICENCE BLOCK *****
 # --------------------------------------------------------------------------
 
-from Blender import *
+from Blender import Mesh, Draw, Window, Texture, Material, sys
 import bpy
 import BPyMesh
 import BPyImage
@@ -49,7 +50,6 @@ import BPyMessages
 try:		import os
 except:		os= False
 
-
 # Generic path functions
 def stripFile(path):
 	'''Return directory, where the file is'''
@@ -125,6 +125,16 @@ def create_materials(filepath, material_libs, unique_materials, unique_material_
 		image= obj_image_load(imagepath, DIR, IMAGE_SEARCH)
 		has_data = image.has_data
 		texture.image = image
+
+		if not has_data:
+			try:
+				# first time using this image. We need to load it first
+				image.glLoad()
+			except:
+				# probably the image is crashed
+				pass
+			else:
+				has_data = image.has_data
 		
 		# Adds textures for materials (rendering)
 		if type == 'Kd':
@@ -167,12 +177,13 @@ def create_materials(filepath, material_libs, unique_materials, unique_material_
 	del temp_mtl
 	
 	#Create new materials
-	for name in unique_materials.iterkeys():
-		unique_materials[name]= bpy.data.materials.new(name)
-		
-		unique_material_images[name]= None, False # assign None to all material images to start with, add to later.
+	for name in unique_materials: # .keys()
+		if name != None:
+			unique_materials[name]= bpy.data.materials.new(name)
+			unique_material_images[name]= None, False # assign None to all material images to start with, add to later.
 		
 	unique_materials[None]= None
+	unique_material_images[None]= None, False
 	
 	for libname in material_libs:
 		mtlpath= DIR + libname
@@ -207,6 +218,7 @@ def create_materials(filepath, material_libs, unique_materials, unique_material_
 						context_material.setIOR( max(1, min(float(line_split[1]), 3))) # Between 1 and 3
 					elif line_lower.startswith('d') or line_lower.startswith('tr'):
 						context_material.setAlpha(float(line_split[1]))
+						context_material.mode |= Material.Modes.ZTRANSP
 					elif line_lower.startswith('map_ka'):
 						img_filepath= line_value(line.split())
 						if img_filepath:
@@ -320,7 +332,7 @@ def split_mesh(verts_loc, faces, unique_materials, filepath, SPLIT_OB_OR_GROUP,
 	return [(value[0], value[1], value[2], key_to_name(key)) for key, value in face_split_dict.iteritems()]
 
 
-def create_mesh(scn, new_objects, has_ngons, CREATE_FGONS, CREATE_EDGES, verts_loc, verts_tex, faces, unique_materials, unique_material_images, unique_smooth_groups, dataname):
+def create_mesh(scn, new_objects, has_ngons, CREATE_FGONS, CREATE_EDGES, verts_loc, verts_tex, faces, unique_materials, unique_material_images, unique_smooth_groups, vertex_groups, dataname):
 	'''
 	Takes all the data gathered and generates a mesh, adding the new object to new_objects
 	deals with fgons, sharp edges and assigning materials
@@ -424,8 +436,8 @@ def create_mesh(scn, new_objects, has_ngons, CREATE_FGONS, CREATE_EDGES, verts_l
 					sharp_edges[key]= None
 	
 	
-	# mat the material names to an index
-	material_mapping= dict([(name, i) for i, name in enumerate(unique_materials.keys())])
+	# map the material names to an index
+	material_mapping= dict([(name, i) for i, name in enumerate(unique_materials)]) # enumerate over unique_materials keys()
 	
 	materials= [None] * len(unique_materials)
 	
@@ -530,6 +542,105 @@ def create_mesh(scn, new_objects, has_ngons, CREATE_FGONS, CREATE_EDGES, verts_l
 	ob= scn.objects.new(me)
 	new_objects.append(ob)
 
+	# Create the vertex groups. No need to have the flag passed here since we test for the 
+	# content of the vertex_groups. If the user selects to NOT have vertex groups saved then
+	# the following test will never run
+	for group_name, group_indicies in vertex_groups.iteritems():
+		me.addVertGroup(group_name)
+		me.assignVertsToGroup(group_name, group_indicies,1.00, Mesh.AssignModes.REPLACE)
+
+
+def create_nurbs(scn, context_nurbs, vert_loc, new_objects):
+	'''
+	Add nurbs object to blender, only support one type at the moment
+	'''
+	deg = context_nurbs.get('deg', (3,))
+	curv_range = context_nurbs.get('curv_range', None)
+	curv_idx = context_nurbs.get('curv_idx', [])
+	parm_u = context_nurbs.get('parm_u', [])
+	parm_v = context_nurbs.get('parm_v', [])
+	name = context_nurbs.get('name', 'ObjNurb')
+	cstype = context_nurbs.get('cstype', None)
+	
+	if cstype == None:
+		print '\tWarning, cstype not found'
+		return
+	if cstype != 'bspline':
+		print '\tWarning, cstype is not supported (only bspline)'
+		return
+	if not curv_idx:
+		print '\tWarning, curv argument empty or not set'
+		return
+	if len(deg) > 1 or parm_v:
+		print '\tWarning, surfaces not supported'
+		return
+	
+	cu = bpy.data.curves.new(name, 'Curve')
+	cu.flag |= 1 # 3D curve
+	
+	nu = None
+	for pt in curv_idx:
+		
+		pt = vert_loc[pt]
+		pt = (pt[0], pt[1], pt[2], 1.0)
+		
+		if nu == None:
+			nu = cu.appendNurb(pt)
+		else:
+			nu.append(pt)
+	
+	nu.orderU = deg[0]+1
+	
+	# get for endpoint flag from the weighting
+	if curv_range and len(parm_u) > deg[0]+1:
+		do_endpoints = True
+		for i in xrange(deg[0]+1):
+			
+			if abs(parm_u[i]-curv_range[0]) > 0.0001:
+				do_endpoints = False
+				break
+			
+			if abs(parm_u[-(i+1)]-curv_range[1]) > 0.0001:
+				do_endpoints = False
+				break
+			
+	else:
+		do_endpoints = False
+	
+	if do_endpoints:
+		nu.flagU |= 2
+	
+	
+	# close
+	'''
+	do_closed = False
+	if len(parm_u) > deg[0]+1:
+		for i in xrange(deg[0]+1):
+			#print curv_idx[i], curv_idx[-(i+1)]
+			
+			if curv_idx[i]==curv_idx[-(i+1)]:
+				do_closed = True
+				break
+	
+	if do_closed:
+		nu.flagU |= 1
+	'''
+	
+	ob = scn.objects.new(cu)
+	new_objects.append(ob)
+
+
+def strip_slash(line_split):
+	if line_split[-1][-1]== '\\':
+		if len(line_split[-1])==1:
+			line_split.pop() # remove the \ item
+		else:
+			line_split[-1]= line_split[-1][:-1] # remove the \ from the end last number
+		return True
+	return False
+
+
+
 def get_float_func(filepath):
 	'''
 	find the float function for this obj file
@@ -537,6 +648,7 @@ def get_float_func(filepath):
 	'''
 	file= open(filepath, 'rU')
 	for line in file: #.xreadlines():
+		line = line.lstrip()
 		if line.startswith('v'): # vn vt v 
 			if ',' in line:
 				return lambda f: float(f.replace(',', '.'))
@@ -546,7 +658,17 @@ def get_float_func(filepath):
 	# incase all vert values were ints 
 	return float
 
-def load_obj(filepath, CLAMP_SIZE= 0.0, CREATE_FGONS= True, CREATE_SMOOTH_GROUPS= True, CREATE_EDGES= True, SPLIT_OBJECTS= True, SPLIT_GROUPS= True, SPLIT_MATERIALS= True, IMAGE_SEARCH=True):
+def load_obj(filepath,
+						 CLAMP_SIZE= 0.0, 
+						 CREATE_FGONS= True, 
+						 CREATE_SMOOTH_GROUPS= True, 
+						 CREATE_EDGES= True, 
+						 SPLIT_OBJECTS= True, 
+						 SPLIT_GROUPS= True, 
+						 SPLIT_MATERIALS= True, 
+						 ROTATE_X90= True, 
+						 IMAGE_SEARCH=True,
+						 POLYGROUPS=False):
 	'''
 	Called by the user interface or another script.
 	load_obj(path) - should give acceptable results.
@@ -555,13 +677,16 @@ def load_obj(filepath, CLAMP_SIZE= 0.0, CREATE_FGONS= True, CREATE_SMOOTH_GROUPS
 	'''
 	print '\nimporting obj "%s"' % filepath
 	
+	if SPLIT_OBJECTS or SPLIT_GROUPS or SPLIT_MATERIALS:
+		POLYGROUPS = False
+	
 	time_main= sys.time()
 	
 	verts_loc= []
 	verts_tex= []
 	faces= [] # tuples of the faces
 	material_libs= [] # filanems to material libs this uses
-	
+	vertex_groups = {} # when POLYGROUPS is true
 	
 	# Get the string to float conversion func for this file- is 'float' for almost all files.
 	float_func= get_float_func(filepath)
@@ -570,7 +695,13 @@ def load_obj(filepath, CLAMP_SIZE= 0.0, CREATE_FGONS= True, CREATE_SMOOTH_GROUPS
 	context_material= None
 	context_smooth_group= None
 	context_object= None
+	context_vgroup = None
 	
+	# Nurbs
+	context_nurbs = {}
+	nurbs = []
+	context_parm = '' # used by nurbs too but could be used elsewhere
+
 	has_ngons= False
 	# has_smoothgroups= False - is explicit with len(unique_smooth_groups) being > 0
 	
@@ -584,12 +715,14 @@ def load_obj(filepath, CLAMP_SIZE= 0.0, CREATE_FGONS= True, CREATE_SMOOTH_GROUPS
 	# it means they are multiline- 
 	# since we use xreadline we cant skip to the next line
 	# so we need to know weather 
-	multi_line_face= False
+	context_multi_line= ''
 	
-	print '\tpassing obj file "%s"...' % filepath,
+	print '\tparsing obj file "%s"...' % filepath,
 	time_sub= sys.time()
+
 	file= open(filepath, 'rU')
 	for line in file: #.xreadlines():
+		line = line.lstrip() # rare cases there is white space at the start of the line
 		
 		if line.startswith('v '):
 			line_split= line.split()
@@ -605,12 +738,11 @@ def load_obj(filepath, CLAMP_SIZE= 0.0, CREATE_FGONS= True, CREATE_SMOOTH_GROUPS
 		
 		# Handel faces lines (as faces) and the second+ lines of fa multiline face here
 		# use 'f' not 'f ' because some objs (very rare have 'fo ' for faces)
-		elif line.startswith('f') or (line.startswith('l ') and CREATE_EDGES) or multi_line_face:
+		elif line.startswith('f') or context_multi_line == 'f':
 			
-			if multi_line_face:
+			if context_multi_line:
 				# use face_vert_loc_indicies and face_vert_tex_indicies previously defined and used the obj_face
 				line_split= line.split()
-				multi_line_face= False
 				
 			else:
 				line_split= line[2:].split()
@@ -626,19 +758,19 @@ def load_obj(filepath, CLAMP_SIZE= 0.0, CREATE_FGONS= True, CREATE_SMOOTH_GROUPS
 				context_object\
 				))
 			
-			if line_split[-1][-1]== '\\':
-				multi_line_face= True
-				if len(line_split[-1])==1:
-					line_split.pop() # remove the \ item
-				else:
-					line_split[-1]= line_split[-1][:-1] # remove the \ from the end last number
-			
-			isline= line.startswith('l')
+			if strip_slash(line_split):
+				context_multi_line = 'f'
+			else:
+				context_multi_line = ''
 			
 			for v in line_split:
 				obj_vert= v.split('/')
 				
 				vert_loc_index= int(obj_vert[0])-1
+				# Add the vertex to the current group
+				# *warning*, this wont work for files that have groups defined around verts
+				if	POLYGROUPS and context_vgroup:
+					vertex_groups[context_vgroup].append(vert_loc_index)
 				
 				# Make relative negative vert indicies absolute
 				if vert_loc_index < 0:
@@ -646,24 +778,60 @@ def load_obj(filepath, CLAMP_SIZE= 0.0, CREATE_FGONS= True, CREATE_SMOOTH_GROUPS
 				
 				face_vert_loc_indicies.append(vert_loc_index)
 				
-				if not isline:
-					if len(obj_vert)>1 and obj_vert[1]:
-						# formatting for faces with normals and textures us 
-						# loc_index/tex_index/nor_index
-						
-						vert_tex_index= int(obj_vert[1])-1
-						# Make relative negative vert indicies absolute
-						if vert_tex_index < 0:
-							vert_tex_index= len(verts_tex) + vert_tex_index + 1
-						
-						face_vert_tex_indicies.append(vert_tex_index)
-					else:
-						# dummy
-						face_vert_tex_indicies.append(0)
+				if len(obj_vert)>1 and obj_vert[1]:
+					# formatting for faces with normals and textures us 
+					# loc_index/tex_index/nor_index
+					
+					vert_tex_index= int(obj_vert[1])-1
+					# Make relative negative vert indicies absolute
+					if vert_tex_index < 0:
+						vert_tex_index= len(verts_tex) + vert_tex_index + 1
+					
+					face_vert_tex_indicies.append(vert_tex_index)
+				else:
+					# dummy
+					face_vert_tex_indicies.append(0)
 			
 			if len(face_vert_loc_indicies) > 4:
 				has_ngons= True
+		
+		elif CREATE_EDGES and (line.startswith('l ') or context_multi_line == 'l'):
+			# very similar to the face load function above with some parts removed
 			
+			if context_multi_line:
+				# use face_vert_loc_indicies and face_vert_tex_indicies previously defined and used the obj_face
+				line_split= line.split()
+				
+			else:
+				line_split= line[2:].split()
+				face_vert_loc_indicies= []
+				face_vert_tex_indicies= []
+				
+				# Instance a face
+				faces.append((\
+				face_vert_loc_indicies,\
+				face_vert_tex_indicies,\
+				context_material,\
+				context_smooth_group,\
+				context_object\
+				))
+			
+			if strip_slash(line_split):
+				context_multi_line = 'l'
+			else:
+				context_multi_line = ''
+			
+			isline= line.startswith('l')
+			
+			for v in line_split:
+				vert_loc_index= int(v)-1
+				
+				# Make relative negative vert indicies absolute
+				if vert_loc_index < 0:
+					vert_loc_index= len(verts_loc) + vert_loc_index + 1
+				
+				face_vert_loc_indicies.append(vert_loc_index)
+		
 		elif line.startswith('s'):
 			if CREATE_SMOOTH_GROUPS:
 				context_smooth_group= line_value(line.split())
@@ -682,12 +850,75 @@ def load_obj(filepath, CLAMP_SIZE= 0.0, CREATE_FGONS= True, CREATE_SMOOTH_GROUPS
 				context_object= line_value(line.split())
 				# print 'context_object', context_object
 				# unique_obects[context_object]= None
+			elif POLYGROUPS:
+				context_vgroup = line_value(line.split())
+				if context_vgroup and context_vgroup != '(null)':
+					vertex_groups.setdefault(context_vgroup, [])
+				else:
+					context_vgroup = None # dont assign a vgroup
 		
 		elif line.startswith('usemtl'):
 			context_material= line_value(line.split())
 			unique_materials[context_material]= None
 		elif line.startswith('mtllib'): # usemap or usemat
 			material_libs.extend( line.split()[1:] ) # can have multiple mtllib filenames per line
+			
+			
+			# Nurbs support
+		elif line.startswith('cstype '):
+			context_nurbs['cstype']= line_value(line.split()) # 'rat bspline' / 'bspline'
+		elif line.startswith('curv ') or context_multi_line == 'curv':
+			line_split= line.split()
+			
+			curv_idx = context_nurbs['curv_idx'] = context_nurbs.get('curv_idx', []) # incase were multiline
+			
+			if not context_multi_line:
+				context_nurbs['curv_range'] = float_func(line_split[1]), float_func(line_split[2])
+				line_split[0:3] = [] # remove first 3 items
+			
+			if strip_slash(line_split):
+				context_multi_line = 'curv'
+			else:
+				context_multi_line = ''
+				
+			
+			for i in line_split:
+				vert_loc_index = int(i)-1
+				
+				if vert_loc_index < 0:
+					vert_loc_index= len(verts_loc) + vert_loc_index + 1
+				
+				curv_idx.append(vert_loc_index)
+			
+		elif line.startswith('parm') or context_multi_line == 'parm':
+			line_split= line.split()
+			
+			if context_multi_line:
+				context_multi_line = ''
+			else:
+				context_parm = line_split[1]
+				line_split[0:2] = [] # remove first 2
+			
+			if strip_slash(line_split):
+				context_multi_line = 'parm'
+			else:
+				context_multi_line = ''
+			
+			if context_parm.lower() == 'u':
+				context_nurbs.setdefault('parm_u', []).extend( [float_func(f) for f in line_split] )
+			elif context_parm.lower() == 'v': # surfaces not suported yet
+				context_nurbs.setdefault('parm_v', []).extend( [float_func(f) for f in line_split] )
+			# else: # may want to support other parm's ?
+		
+		elif line.startswith('deg '):
+			context_nurbs['deg']= [int(i) for i in line.split()[1:]]
+		elif line.startswith('end'):
+			# Add the nurbs curve
+			if context_object:
+				context_nurbs['name'] = context_object
+			nurbs.append(context_nurbs)
+			context_nurbs = {}
+			context_parm = ''
 		
 		''' # How to use usemap? depricated?
 		elif line.startswith('usema'): # usemap or usemat
@@ -707,6 +938,8 @@ def load_obj(filepath, CLAMP_SIZE= 0.0, CREATE_FGONS= True, CREATE_SMOOTH_GROUPS
 	print '%.4f sec' % (time_new-time_sub)
 	time_sub= time_new
 	
+	if not ROTATE_X90:
+		verts_loc[:] = [(v[0], v[2], -v[1]) for v in verts_loc]
 	
 	# deselect all
 	scn = bpy.data.scenes.active
@@ -719,8 +952,13 @@ def load_obj(filepath, CLAMP_SIZE= 0.0, CREATE_FGONS= True, CREATE_SMOOTH_GROUPS
 	else:								SPLIT_OB_OR_GROUP = False
 	
 	for verts_loc_split, faces_split, unique_materials_split, dataname in split_mesh(verts_loc, faces, unique_materials, filepath, SPLIT_OB_OR_GROUP, SPLIT_MATERIALS):
-		# Create meshes from the data
-		create_mesh(scn, new_objects, has_ngons, CREATE_FGONS, CREATE_EDGES, verts_loc_split, verts_tex, faces_split, unique_materials_split, unique_material_images, unique_smooth_groups, dataname)
+		# Create meshes from the data, warning 'vertex_groups' wont support splitting
+		create_mesh(scn, new_objects, has_ngons, CREATE_FGONS, CREATE_EDGES, verts_loc_split, verts_tex, faces_split, unique_materials_split, unique_material_images, unique_smooth_groups, vertex_groups, dataname)
+	
+	# nurbs support
+	for context_nurbs in nurbs:
+		create_nurbs(scn, context_nurbs, verts_loc, new_objects)
+	
 	
 	axis_min= [ 1000000000]*3
 	axis_max= [-1000000000]*3
@@ -743,6 +981,11 @@ def load_obj(filepath, CLAMP_SIZE= 0.0, CREATE_FGONS= True, CREATE_SMOOTH_GROUPS
 		for ob in new_objects:
 			ob.setSize(scale, scale, scale)
 	
+	# Better rotate the vert locations
+	#if not ROTATE_X90:
+	#	for ob in new_objects:
+	#		ob.RotX = -1.570796326794896558
+	
 	time_new= sys.time()
 	
 	print '%.4f sec' % (time_new-time_sub)
@@ -756,19 +999,24 @@ def load_obj_ui(filepath, BATCH_LOAD= False):
 	if BPyMessages.Error_NoFile(filepath):
 		return
 	
+	global CREATE_SMOOTH_GROUPS, CREATE_FGONS, CREATE_EDGES, SPLIT_OBJECTS, SPLIT_GROUPS, SPLIT_MATERIALS, CLAMP_SIZE, IMAGE_SEARCH, POLYGROUPS, KEEP_VERT_ORDER, ROTATE_X90
 	
 	CREATE_SMOOTH_GROUPS= Draw.Create(0)
 	CREATE_FGONS= Draw.Create(1)
 	CREATE_EDGES= Draw.Create(1)
-	SPLIT_OBJECTS= Draw.Create(1)
-	SPLIT_GROUPS= Draw.Create(1)
-	SPLIT_MATERIALS= Draw.Create(1)
-	KEEP_VERT_ORDER= Draw.Create(1)
+	SPLIT_OBJECTS= Draw.Create(0)
+	SPLIT_GROUPS= Draw.Create(0)
+	SPLIT_MATERIALS= Draw.Create(0)
 	CLAMP_SIZE= Draw.Create(10.0)
 	IMAGE_SEARCH= Draw.Create(1)
+	POLYGROUPS= Draw.Create(0)
+	KEEP_VERT_ORDER= Draw.Create(1)
+	ROTATE_X90= Draw.Create(1)
 	
 	
 	# Get USER Options
+	# Note, Works but not pretty, instead use a more complicated GUI
+	'''
 	pup_block= [\
 	'Import...',\
 	('Smooth Groups', CREATE_SMOOTH_GROUPS, 'Surround smooth groups by sharp edges'),\
@@ -791,6 +1039,111 @@ def load_obj_ui(filepath, BATCH_LOAD= False):
 		SPLIT_OBJECTS.val = False
 		SPLIT_GROUPS.val = False
 		SPLIT_MATERIALS.val = False
+	'''
+	
+	
+	
+	# BEGIN ALTERNATIVE UI *******************
+	if True: 
+		
+		EVENT_NONE = 0
+		EVENT_EXIT = 1
+		EVENT_REDRAW = 2
+		EVENT_IMPORT = 3
+		
+		GLOBALS = {}
+		GLOBALS['EVENT'] = EVENT_REDRAW
+		#GLOBALS['MOUSE'] = Window.GetMouseCoords()
+		GLOBALS['MOUSE'] = [i/2 for i in Window.GetScreenSize()]
+		
+		def obj_ui_set_event(e,v):
+			GLOBALS['EVENT'] = e
+		
+		def do_split(e,v):
+			global SPLIT_OBJECTS, SPLIT_GROUPS, SPLIT_MATERIALS, KEEP_VERT_ORDER, POLYGROUPS
+			if SPLIT_OBJECTS.val or SPLIT_GROUPS.val or SPLIT_MATERIALS.val:
+				KEEP_VERT_ORDER.val = 0
+				POLYGROUPS.val = 0
+			else:
+				KEEP_VERT_ORDER.val = 1
+			
+		def do_vertorder(e,v):
+			global SPLIT_OBJECTS, SPLIT_GROUPS, SPLIT_MATERIALS, KEEP_VERT_ORDER
+			if KEEP_VERT_ORDER.val:
+				SPLIT_OBJECTS.val = SPLIT_GROUPS.val = SPLIT_MATERIALS.val = 0
+			else:
+				if not (SPLIT_OBJECTS.val or SPLIT_GROUPS.val or SPLIT_MATERIALS.val):
+					KEEP_VERT_ORDER.val = 1
+			
+		def do_polygroups(e,v):
+			global SPLIT_OBJECTS, SPLIT_GROUPS, SPLIT_MATERIALS, KEEP_VERT_ORDER, POLYGROUPS
+			if POLYGROUPS.val:
+				SPLIT_OBJECTS.val = SPLIT_GROUPS.val = SPLIT_MATERIALS.val = 0
+			
+		def do_help(e,v):
+			url = __url__[0]
+			print 'Trying to open web browser with documentation at this address...'
+			print '\t' + url
+			
+			try:
+				import webbrowser
+				webbrowser.open(url)
+			except:
+				print '...could not open a browser window.'
+		
+		def obj_ui():
+			ui_x, ui_y = GLOBALS['MOUSE']
+			
+			# Center based on overall pup size
+			ui_x -= 165
+			ui_y -= 90
+			
+			global CREATE_SMOOTH_GROUPS, CREATE_FGONS, CREATE_EDGES, SPLIT_OBJECTS, SPLIT_GROUPS, SPLIT_MATERIALS, CLAMP_SIZE, IMAGE_SEARCH, POLYGROUPS, KEEP_VERT_ORDER, ROTATE_X90
+			
+			Draw.Label('Import...', ui_x+9, ui_y+159, 220, 21)
+			Draw.BeginAlign()
+			CREATE_SMOOTH_GROUPS = Draw.Toggle('Smooth Groups', EVENT_NONE, ui_x+9, ui_y+139, 110, 20, CREATE_SMOOTH_GROUPS.val, 'Surround smooth groups by sharp edges')
+			CREATE_FGONS = Draw.Toggle('NGons as FGons', EVENT_NONE, ui_x+119, ui_y+139, 110, 20, CREATE_FGONS.val, 'Import faces with more then 4 verts as fgons')
+			CREATE_EDGES = Draw.Toggle('Lines as Edges', EVENT_NONE, ui_x+229, ui_y+139, 110, 20, CREATE_EDGES.val, 'Import lines and faces with 2 verts as edges')
+			Draw.EndAlign()
+			
+			Draw.Label('Separate objects by OBJ...', ui_x+9, ui_y+110, 220, 20)
+			Draw.BeginAlign()
+			SPLIT_OBJECTS = Draw.Toggle('Object', EVENT_REDRAW, ui_x+9, ui_y+89, 55, 21, SPLIT_OBJECTS.val, 'Import OBJ Objects into Blender Objects', do_split)
+			SPLIT_GROUPS = Draw.Toggle('Group', EVENT_REDRAW, ui_x+64, ui_y+89, 55, 21, SPLIT_GROUPS.val, 'Import OBJ Groups into Blender Objects', do_split)
+			SPLIT_MATERIALS = Draw.Toggle('Material', EVENT_REDRAW, ui_x+119, ui_y+89, 60, 21, SPLIT_MATERIALS.val, 'Import each material into a seperate mesh (Avoids > 16 per mesh error)', do_split)
+			Draw.EndAlign()
+			
+			# Only used for user feedback
+			KEEP_VERT_ORDER = Draw.Toggle('Keep Vert Order', EVENT_REDRAW, ui_x+184, ui_y+89, 113, 21, KEEP_VERT_ORDER.val, 'Keep vert and face order, disables split options, enable for morph targets', do_vertorder)
+			
+			ROTATE_X90 = Draw.Toggle('-X90', EVENT_REDRAW, ui_x+302, ui_y+89, 38, 21, ROTATE_X90.val, 'Rotate X 90.')
+			
+			Draw.Label('Options...', ui_x+9, ui_y+60, 211, 20)
+			CLAMP_SIZE = Draw.Number('Clamp Scale: ', EVENT_NONE, ui_x+9, ui_y+39, 130, 21, CLAMP_SIZE.val, 0.0, 1000.0, 'Clamp the size to this maximum (Zero to Disable)')
+			POLYGROUPS = Draw.Toggle('Poly Groups', EVENT_REDRAW, ui_x+144, ui_y+39, 90, 21, POLYGROUPS.val, 'Import OBJ groups as vertex groups.', do_polygroups)
+			IMAGE_SEARCH = Draw.Toggle('Image Search', EVENT_NONE, ui_x+239, ui_y+39, 100, 21, IMAGE_SEARCH.val, 'Search subdirs for any assosiated images (Warning, may be slow)')
+			Draw.BeginAlign()
+			Draw.PushButton('Online Help', EVENT_REDRAW, ui_x+9, ui_y+9, 110, 21, 'Load the wiki page for this script', do_help)
+			Draw.PushButton('Cancel', EVENT_EXIT, ui_x+119, ui_y+9, 110, 21, '', obj_ui_set_event)
+			Draw.PushButton('Import', EVENT_IMPORT, ui_x+229, ui_y+9, 110, 21, 'Import with these settings', obj_ui_set_event)
+			Draw.EndAlign()
+			
+		
+		# hack so the toggle buttons redraw. this is not nice at all
+		while GLOBALS['EVENT'] not in (EVENT_EXIT, EVENT_IMPORT):
+			Draw.UIBlock(obj_ui, 0)
+		
+		if GLOBALS['EVENT'] != EVENT_IMPORT:
+			return
+		
+	# END ALTERNATIVE UI *********************
+	
+	
+	
+	
+	
+	
 	
 	Window.WaitCursor(1)
 	
@@ -819,7 +1172,9 @@ def load_obj_ui(filepath, BATCH_LOAD= False):
 			  SPLIT_OBJECTS.val,\
 			  SPLIT_GROUPS.val,\
 			  SPLIT_MATERIALS.val,\
+			  ROTATE_X90.val,\
 			  IMAGE_SEARCH.val,\
+			  POLYGROUPS.val
 			)
 	
 	else: # Normal load
@@ -831,7 +1186,9 @@ def load_obj_ui(filepath, BATCH_LOAD= False):
 		  SPLIT_OBJECTS.val,\
 		  SPLIT_GROUPS.val,\
 		  SPLIT_MATERIALS.val,\
+		  ROTATE_X90.val,\
 		  IMAGE_SEARCH.val,\
+		  POLYGROUPS.val
 		)
 	
 	Window.WaitCursor(0)
@@ -848,34 +1205,28 @@ if __name__=='__main__' and not DEBUG:
 	else:
 		Window.FileSelector(load_obj_ui, 'Import a Wavefront OBJ', '*.obj')
 
-
+	# For testing compatibility
 '''
-# For testing compatibility
 else:
 	# DEBUG ONLY
 	TIME= sys.time()
+	DIR = '/fe/obj'
 	import os
 	print 'Searching for files'
-	os.system('find /fe/obj -iname "*.obj" > /tmp/temp3ds_list')
+	def fileList(path):
+		for dirpath, dirnames, filenames in os.walk(path):
+			for filename in filenames:
+				yield os.path.join(dirpath, filename)
 	
-	print '...Done'
-	file= open('/tmp/temp3ds_list', 'rU')
-	lines= file.readlines()
-	file.close()
-
-	def between(v,a,b):
-		if v <= max(a,b) and v >= min(a,b):
-			return True		
-		return False
-		
-	for i, _obj in enumerate(lines):
-		if between(i, 0,20):
-			_obj= _obj[:-1]
-			print 'Importing', _obj, '\nNUMBER', i, 'of', len(lines)
-			_obj_file= _obj.split('/')[-1].split('\\')[-1]
-			newScn= bpy.data.scenes.new(_obj_file)
+	files = [f for f in fileList(DIR) if f.lower().endswith('.obj')]
+	files.sort()
+	
+	for i, obj_file in enumerate(files):
+		if 0 < i < 20:
+			print 'Importing', obj_file, '\nNUMBER', i, 'of', len(files)
+			newScn= bpy.data.scenes.new(os.path.basename(obj_file))
 			newScn.makeCurrent()
-			load_obj(_obj, False)
+			load_obj(obj_file, False, IMAGE_SEARCH=0)
 
 	print 'TOTAL TIME: %.6f' % (sys.time() - TIME)
 '''
